@@ -5,7 +5,6 @@
 // TODO web sockets
 // TODO admin area
 // TODO keep subscribed topics as chunks
-use tokio::sync::mpsc;
 use tokio::sync::RwLock;
 use tokio::task::JoinHandle;
 use tokio_rustls::webpki;
@@ -243,21 +242,21 @@ pub struct Message {
 }
 
 impl Message {
+    #[inline]
     pub fn topic(&self) -> &str {
         &self.topic
     }
-
+    #[inline]
     pub fn data(&self) -> &[u8] {
         &self.data
     }
-
     /// # Errors
     ///
     /// Will return Err if data is unable to be parsed as bytes
+    #[inline]
     pub fn data_as_str(&self) -> Result<&str, std::str::Utf8Error> {
         std::str::from_utf8(&self.data)
     }
-
     /// # Errors
     ///
     /// Will return Err on buffer parse errors
@@ -280,7 +279,7 @@ impl Message {
 pub struct ServerClientData {
     login: String,
     token: Token,
-    pub data_channel: RwLock<Option<mpsc::Sender<Arc<MessageFrame>>>>,
+    pub data_channel: RwLock<Option<async_channel::Sender<Arc<MessageFrame>>>>,
     pub tasks: RwLock<Vec<JoinHandle<Result<(), Error>>>>,
 }
 
@@ -402,8 +401,8 @@ impl ServerClientDB {
     pub async fn register_data_channel(
         &mut self,
         token: &Token,
-        channel: mpsc::Sender<Arc<MessageFrame>>,
-    ) -> Result<(mpsc::Sender<Arc<MessageFrame>>, ServerClient), Error> {
+        channel: async_channel::Sender<Arc<MessageFrame>>,
+    ) -> Result<(async_channel::Sender<Arc<MessageFrame>>, ServerClient), Error> {
         if let Some(ref mut client) = self.clients_by_token.get_mut(token) {
             let mut dc = client.data_channel.write().await;
             if dc.is_some() {
@@ -613,10 +612,10 @@ pub fn now_ns() -> u64 {
 pub mod acl;
 pub mod client;
 pub mod comm;
-#[cfg(feature = "cluster")]
-pub mod replication;
 #[cfg(feature = "server")]
 pub mod passwords;
+#[cfg(feature = "cluster")]
+pub mod replication;
 
 #[cfg(test)]
 mod test {
